%define anolis_release 3
# Rolling_version represents the first rolling version of the current version taken from github. 
# Please increment this field when the rolling version of 2.1 is updated later.
%define rolling_version 2

Name:           luajit
Epoch:  	1
Version:        2.1
Release:        %{rolling_version}.%{anolis_release}%{?dist}
Summary:        Just-In-Time Compiler for Lua
License:        MIT
URL:            http://luajit.org/
Source0: 	https://github.com/LuaJIT/LuaJIT/archive/refs/tags/v%{version}.ROLLING.tar.gz
Source1:        https://github.com/LuaJIT/LuaJIT-test-cleanup/archive/refs/heads/master/LuaJIT-test-cleanup.tar.gz

# Add 'make check'
Patch0: luajit-2.1-make-check.patch
Patch1: 0001-LoongArch64-Add-target-architecture-selection.patch
Patch2: 0002-LoongArch64-Add-DynASM-support.patch
Patch3: 0003-LoongArch64-Add-register-assignments-for-the-interpr.patch
Patch4: 0004-LoongArch64-Add-stack-layout.patch
Patch5: 0005-LoongArch64-Add-some-general-macro-type-definitions-.patch
Patch6: 0006-LoongArch64-Add-pure-interpreter-backend.patch
Patch7: 0007-LoongArch64-Add-definitions-for-target-CPU.patch
Patch8: 0008-LoongArch64-Add-some-constant-definitions.patch
Patch9: 0009-LoongArch64-Add-LoongArch-instruction-emitter.patch
Patch10: 0010-LoongArch64-Add-IR-assembler-support.patch
Patch11: 0011-LoongArch64-Add-JIT-support-in-the-interpreter.patch
Patch12: 0012-LoongArch64-Add-CPU-feature-detection-when-init-JIT-.patch
Patch13: 0013-LoongArch64-Add-LoongArch-lp64-calling-conventions-a.patch
Patch14: 0014-LoongArch64-Add-FFI-C-callback-handling.patch
Patch15: 0015-LoongArch64-Add-FFI-support-in-the-interpreter.patch
Patch16: 0016-LoongArch64-Add-DWARF-and-ELF-header-definitions.patch
Patch17: 0017-LoongArch64-Add-support-for-LuaJIT-VM-builder.patch
Patch18: 0018-LoongArch64-Add-loongarch64-support-when-save-list-b.patch
Patch19: 0019-LoongArch64-Add-LoongArch64-disassembler-module.patch
Patch20: 0020-LoongArch64-Add-support-in-Makefile.patch
Patch21: 0021-LoongArch64-Upgrade-the-code-to-v2.1.ROLLING.patch
Patch22: LuaJIT-2.1-add-sw_64-support.patch
Patch23: LuaJIT-2.1-add-riscv64-support.patch

BuildRequires:  gcc
BuildRequires:  make

%description
LuaJIT implements the full set of language features defined by Lua 5.1.
The virtual machine (VM) is API- and ABI-compatible to the standard
Lua interpreter and can be deployed as a drop-in replacement.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description devel
This package contains development files for %{name}.

%package doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
BuildArch:      noarch

%description doc
Doc files for %{name}

%prep
%setup -n LuaJIT-%{version}.ROLLING -q
tar -xzf %{SOURCE1} -C .
%patch -P0 -p1
%patch -P1 -p1
%patch -P2 -p1
%patch -P3 -p1
%patch -P4 -p1
%patch -P5 -p1
%patch -P6 -p1
%patch -P7 -p1
%patch -P8 -p1
%patch -P9 -p1
%patch -P10 -p1
%patch -P11 -p1
%patch -P12 -p1
%patch -P13 -p1
%patch -P14 -p1
%patch -P15 -p1
%patch -P16 -p1
%patch -P17 -p1
%patch -P18 -p1
%patch -P19 -p1
%patch -P20 -p1
%patch -P21 -p1
%ifarch sw_64
%patch -P22 -p1
%endif
%ifarch riscv64
%patch -P23 -p1
%endif

ln -s LuaJIT-test-cleanup-master/bench bench
ln -s LuaJIT-test-cleanup-master/test test

# Enable Lua 5.2 features
sed -i -e '/-DLUAJIT_ENABLE_LUA52COMPAT/s/^#//' src/Makefile

# preserve timestamps (cicku)
sed -i -e '/install -m/s/-m/-p -m/' Makefile

%build
# Q= - enable verbose output
# E= @: - disable @echo messages
# NOTE: we use amalgamated build as per documentation suggestion doc/install.html
make amalg Q= E=@: PREFIX=%{_prefix} TARGET_STRIP=: \
           CFLAGS="%{build_cflags}" LDFLAGS="%{build_ldflags}" \
           MULTILIB=%{_lib} %{?_smp_mflags}

%install
# PREREL= - disable -betaX suffix
# INSTALL_TNAME - executable name
%make_install PREFIX=%{_prefix} \
              MULTILIB=%{_lib}

rm -rf _tmp_html ; mkdir _tmp_html
cp -a doc _tmp_html/html

# fix the bin name error
mv %{buildroot}/%{_bindir}/luajit-%{version}. %{buildroot}/%{_bindir}/luajit-%{version}
cp %{buildroot}/%{_bindir}/luajit-%{version} %{buildroot}/%{_bindir}/luajit

# Remove static .a
find %{buildroot} -type f -name *.a -delete -print

%check
# Don't fail the build on a check failure.
make check || true

%files
%license COPYRIGHT
%{_bindir}/%{name}
%{_bindir}/%{name}-%{version}
%{_libdir}/lib%{name}-*.so.*
%{_mandir}/man1/%{name}.1*
%{_datadir}/%{name}-%{version}/

%files devel
%doc _tmp_html/html/
%{_includedir}/%{name}-%{version}/
%{_libdir}/lib%{name}-*.so
%{_libdir}/pkgconfig/%{name}.pc

%files doc
%doc README

%changelog
* Thu May 8 2025 Yihao Yan <yan.yihao@zte.com.cn> - 1:2.1-2.3
- add support for riscv64

* Mon Mar 17 2025 xunian <xunian@nfschina.com> - 1:2.1-2.2
- Add sw64 support

* Mon Jan 15 2024 Huang Qiqi <huangqiqi@loongson.cn> - 1:2.1-2.1
- add patch to support LoongArch

* Wed Dec 20 2023 happy_orange <songnannan@linux.alibaba.com> - 1:2.1-1.1
- update to 2.1-ROLLINGe

* Wed Feb 15 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.1.0-0.26beta3
- init from upstream
